
0.4.3 (2015-12-04)
##################

Changes since 0.4.2 (2015-09-30).

New Features
$$$$$$$$$$$$

* closes `#281 <https://github.com/biocommons/hgvs/issues/281/>`_: install hgvs-shell executable with package [`BROKEN: bece4e961cd4 <https://github.com/biocommons/hgvs/commit/bece4e961cd4>`_]

Other Changes
$$$$$$$$$$$$$

* closes `#289 <https://github.com/biocommons/hgvs/issues/289/>`_: work around pycharm bug `PY-4213 <https://youtrack.jetbrains.com/issue/PY-4213>`__ [`BROKEN: 19c0d4fefbfd <https://github.com/biocommons/hgvs/commit/19c0d4fefbfd>`_]
* added 0.4.2 changelog (after the tagged commit :-() [`BROKEN: 4a596322bceb <https://github.com/biocommons/hgvs/commit/4a596322bceb>`_]
